<?php
/**
* Social profiles options
*
* @package GridRead WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridread_social_profiles($wp_customize) {

    $wp_customize->add_section( 'gridread_section_social', array( 'title' => esc_html__( 'Social Links Options', 'gridread' ), 'panel' => 'gridread_main_options_panel', 'priority' => 240, ));

    $wp_customize->add_setting( 'gridread_options[hide_social_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridread_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridread_hide_social_buttons_control', array( 'label' => esc_html__( 'Hide Social + Search + Login/Logout Buttons', 'gridread' ), 'description' => esc_html__('If you checked this option, there is no any effect from these option: "Hide Search Button", "Show Login/Logout Button", "Show Random Post Button".', 'gridread'), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[hide_social_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridread_options[hide_search_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridread_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridread_hide_search_button_control', array( 'label' => esc_html__( 'Hide Search Button', 'gridread' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'gridread'), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[hide_search_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridread_options[show_login_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridread_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridread_show_login_button_control', array( 'label' => esc_html__( 'Show Login/Logout Button', 'gridread' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'gridread'), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[show_login_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridread_options[twitterlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_twitterlink_control', array( 'label' => esc_html__( 'X URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[twitterlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[facebooklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_facebooklink_control', array( 'label' => esc_html__( 'Facebook URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[facebooklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[threadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_threadslink_control', array( 'label' => esc_html__( 'Threads URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[threadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[pinterestlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_pinterestlink_control', array( 'label' => esc_html__( 'Pinterest URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[pinterestlink]', 'type' => 'text' ) );
    
    $wp_customize->add_setting( 'gridread_options[linkedinlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_linkedinlink_control', array( 'label' => esc_html__( 'Linkedin Link', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[linkedinlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[instagramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_instagramlink_control', array( 'label' => esc_html__( 'Instagram Link', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[instagramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[vklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_vklink_control', array( 'label' => esc_html__( 'VK Link', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[vklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[flickrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_flickrlink_control', array( 'label' => esc_html__( 'Flickr Link', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[flickrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[youtubelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_youtubelink_control', array( 'label' => esc_html__( 'Youtube URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[youtubelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[vimeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_vimeolink_control', array( 'label' => esc_html__( 'Vimeo URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[vimeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[soundcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_soundcloudlink_control', array( 'label' => esc_html__( 'Soundcloud URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[soundcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[messengerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_messengerlink_control', array( 'label' => esc_html__( 'Messenger URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[messengerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[whatsapplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_whatsapplink_control', array( 'label' => esc_html__( 'WhatsApp URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[whatsapplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[tiktoklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_tiktoklink_control', array( 'label' => esc_html__( 'TikTok URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[tiktoklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[lastfmlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_lastfmlink_control', array( 'label' => esc_html__( 'Lastfm URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[lastfmlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[mediumlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_mediumlink_control', array( 'label' => esc_html__( 'Medium URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[mediumlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[githublink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_githublink_control', array( 'label' => esc_html__( 'Github URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[githublink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[bitbucketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_bitbucketlink_control', array( 'label' => esc_html__( 'Bitbucket URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[bitbucketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[tumblrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_tumblrlink_control', array( 'label' => esc_html__( 'Tumblr URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[tumblrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[digglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_digglink_control', array( 'label' => esc_html__( 'Digg URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[digglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[deliciouslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_deliciouslink_control', array( 'label' => esc_html__( 'Delicious URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[deliciouslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[stumblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_stumblelink_control', array( 'label' => esc_html__( 'Stumbleupon URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[stumblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[mixlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_mixlink_control', array( 'label' => esc_html__( 'Mix URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[mixlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[redditlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_redditlink_control', array( 'label' => esc_html__( 'Reddit URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[redditlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[dribbblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_dribbblelink_control', array( 'label' => esc_html__( 'Dribbble URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[dribbblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[flipboardlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_flipboardlink_control', array( 'label' => esc_html__( 'Flipboard URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[flipboardlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[bloggerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_bloggerlink_control', array( 'label' => esc_html__( 'Blogger URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[bloggerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[etsylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_etsylink_control', array( 'label' => esc_html__( 'Etsy URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[etsylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[behancelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_behancelink_control', array( 'label' => esc_html__( 'Behance URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[behancelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[amazonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_amazonlink_control', array( 'label' => esc_html__( 'Amazon URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[amazonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[meetuplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_meetuplink_control', array( 'label' => esc_html__( 'Meetup URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[meetuplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[mixcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_mixcloudlink_control', array( 'label' => esc_html__( 'Mixcloud URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[mixcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[slacklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_slacklink_control', array( 'label' => esc_html__( 'Slack URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[slacklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[snapchatlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_snapchatlink_control', array( 'label' => esc_html__( 'Snapchat URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[snapchatlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[spotifylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_spotifylink_control', array( 'label' => esc_html__( 'Spotify URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[spotifylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[yelplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_yelplink_control', array( 'label' => esc_html__( 'Yelp URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[yelplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[wordpresslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_wordpresslink_control', array( 'label' => esc_html__( 'WordPress URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[wordpresslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[twitchlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_twitchlink_control', array( 'label' => esc_html__( 'Twitch URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[twitchlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[telegramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_telegramlink_control', array( 'label' => esc_html__( 'Telegram URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[telegramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[bandcamplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_bandcamplink_control', array( 'label' => esc_html__( 'Bandcamp URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[bandcamplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[quoralink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_quoralink_control', array( 'label' => esc_html__( 'Quora URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[quoralink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[foursquarelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_foursquarelink_control', array( 'label' => esc_html__( 'Foursquare URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[foursquarelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[deviantartlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_deviantartlink_control', array( 'label' => esc_html__( 'DeviantArt URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[deviantartlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[imdblink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_imdblink_control', array( 'label' => esc_html__( 'IMDB URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[imdblink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[codepenlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_codepenlink_control', array( 'label' => esc_html__( 'Codepen URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[codepenlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[jsfiddlelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_jsfiddlelink_control', array( 'label' => esc_html__( 'JSFiddle URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[jsfiddlelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[stackoverflowlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_stackoverflowlink_control', array( 'label' => esc_html__( 'Stack Overflow URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[stackoverflowlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[stackexchangelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_stackexchangelink_control', array( 'label' => esc_html__( 'Stack Exchange URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[stackexchangelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[bsalink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_bsalink_control', array( 'label' => esc_html__( 'BuySellAds URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[bsalink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[web500pxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_web500pxlink_control', array( 'label' => esc_html__( '500px URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[web500pxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[ellolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_ellolink_control', array( 'label' => esc_html__( 'Ello URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[ellolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[discordlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_discordlink_control', array( 'label' => esc_html__( 'Discord URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[discordlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[goodreadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_goodreadslink_control', array( 'label' => esc_html__( 'Goodreads URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[goodreadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[odnoklassnikilink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_odnoklassnikilink_control', array( 'label' => esc_html__( 'Odnoklassniki URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[odnoklassnikilink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[houzzlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_houzzlink_control', array( 'label' => esc_html__( 'Houzz URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[houzzlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[pocketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_pocketlink_control', array( 'label' => esc_html__( 'Pocket URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[pocketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[xinglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_xinglink_control', array( 'label' => esc_html__( 'XING URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[xinglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[mastodonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_mastodonlink_control', array( 'label' => esc_html__( 'Mastodon URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[mastodonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[blueskylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_blueskylink_control', array( 'label' => esc_html__( 'Bluesky URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[blueskylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[googleplaylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_googleplaylink_control', array( 'label' => esc_html__( 'Google Play URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[googleplaylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[slidesharelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_slidesharelink_control', array( 'label' => esc_html__( 'SlideShare URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[slidesharelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[dropboxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_dropboxlink_control', array( 'label' => esc_html__( 'Dropbox URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[dropboxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[paypallink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_paypallink_control', array( 'label' => esc_html__( 'PayPal URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[paypallink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[viadeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_viadeolink_control', array( 'label' => esc_html__( 'Viadeo URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[viadeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[wikipedialink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_wikipedialink_control', array( 'label' => esc_html__( 'Wikipedia URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[wikipedialink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[skypeusername]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridread_skypeusername_control', array( 'label' => esc_html__( 'Skype Username', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[skypeusername]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[emailaddress]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridread_sanitize_email' ) );

    $wp_customize->add_control( 'gridread_emailaddress_control', array( 'label' => esc_html__( 'Email Address', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[emailaddress]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridread_options[rsslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridread_rsslink_control', array( 'label' => esc_html__( 'RSS Feed URL', 'gridread' ), 'section' => 'gridread_section_social', 'settings' => 'gridread_options[rsslink]', 'type' => 'text' ) );

}