<?php
/**
* Layout Functions
*
* @package GridRead WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridread_hide_footer_widgets() {
    $hide_footer_widgets = false;

    if ( gridread_get_option('hide_footer_widgets') ) {
        $hide_footer_widgets = true;
    }

    return apply_filters( 'gridread_hide_footer_widgets', $hide_footer_widgets );
}

function gridread_is_header_content_active() {
    $header_content_active = true;

    if ( gridread_get_option('hide_header_content') ) {
        $header_content_active = false;
    }

    return apply_filters( 'gridread_is_header_content_active', $header_content_active );
}

function gridread_is_primary_menu_active() {
    $primary_menu_active = true;

    if ( gridread_get_option('disable_primary_menu') ) {
        $primary_menu_active = false;
    }

    return apply_filters( 'gridread_is_primary_menu_active', $primary_menu_active );
}

function gridread_is_secondary_menu_active() {
    $secondary_menu_active = true;

    if ( gridread_get_option('disable_secondary_menu') ) {
        $secondary_menu_active = false;
    }

    return apply_filters( 'gridread_is_secondary_menu_active', $secondary_menu_active );
}

function gridread_is_social_buttons_active() {
    $social_buttons_active = true;

    if ( gridread_get_option('hide_social_buttons') ) {
        $social_buttons_active = false;
    }

    return apply_filters( 'gridread_is_social_buttons_active', $social_buttons_active );
}

function gridread_is_fitvids_active() {
    $fitvids_active = false;

    if ( gridread_get_option('enable_fitvids') ) {
        $fitvids_active = true;
    }

    return apply_filters( 'gridread_is_fitvids_active', $fitvids_active );
}

function gridread_is_backtotop_active() {
    $backtotop_active = true;

    if ( gridread_get_option('disable_backtotop') ) {
        $backtotop_active = false;
    }

    return apply_filters( 'gridread_is_backtotop_active', $backtotop_active );
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function gridread_content_width() {
    $content_width = 1074;

    if ( is_singular() ) {
        if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-post.php' ) ) ) {
           $content_width = 1422;
        } else {
            $content_width = 1074;
        }
    } else {
        $content_width = 1422;
    }

    $GLOBALS['content_width'] = apply_filters( 'gridread_content_width', $content_width ); /* phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound */
}
add_action( 'template_redirect', 'gridread_content_width', 0 );

function gridread_post_summaries_style() {
   $summaries_style = 'grid';
    if ( gridread_get_option('post_summaries_style') ) {
        $summaries_style = gridread_get_option('post_summaries_style');
    }
   return apply_filters( 'gridread_post_summaries_style', $summaries_style );
}

function gridread_is_slider_active() {
    $slider_active = false;

    if ( gridread_get_option('enable_slider') ) {
        $slider_active = true;
    }

    return apply_filters( 'gridread_is_slider_active', $slider_active );
}