<?php
/**
* Post meta functions
*
* @package GridRead WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

if ( ! function_exists( 'gridread_post_tags' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function gridread_post_tags() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'gridread' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */
            printf( '<span class="gridread-tags-links"><i class="fas fa-tags" aria-hidden="true"></i> ' . esc_html__( 'Tagged %1$s', 'gridread' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridread_grid_cats' ) ) :
function gridread_grid_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( '&nbsp;', 'gridread' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<div class="gridread-grid-post-categories">' . __( '<span class="gridread-sr-only">Posted in </span>%1$s', 'gridread' ) . '</div>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridread_grid_postmeta' ) ) :
function gridread_grid_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( gridread_get_option('show_post_author_home') || !(gridread_get_option('hide_posted_date_home')) || (gridread_get_option('show_comments_link_home') && (! post_password_required() && ( comments_open() || get_comments_number() ))) ) { ?>
    <div class="gridread-grid-post-footer gridread-grid-post-block">
    <div class="gridread-grid-post-footer-inside">
    <?php if ( gridread_get_option('show_post_author_home') ) { ?><span class="gridread-grid-post-author gridread-grid-post-meta"><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span><?php } ?>
    <?php if ( !(gridread_get_option('hide_posted_date_home')) ) { ?><span class="gridread-grid-post-date gridread-grid-post-meta"><?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( gridread_get_option('show_comments_link_home') && (! post_password_required() && ( comments_open() || get_comments_number() )) ) { ?><span class="gridread-grid-post-comments gridread-grid-post-meta"><?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( '0 Comment<span class="gridread-sr-only"> on %s</span>', 'gridread' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span><?php } ?>
    </div>
    </div>
    <?php } ?>
<?php }
endif;


function gridread_is_grid_postmeta_active() {
    global $post;
    $grid_postmeta_active = false;
    if ( gridread_get_option('show_post_author_home') || !(gridread_get_option('hide_posted_date_home')) || (gridread_get_option('show_comments_link_home') && (! post_password_required() && ( comments_open() || get_comments_number() ))) ) {
        $grid_postmeta_active = true;
    }
    return apply_filters( 'gridread_is_grid_postmeta_active', $grid_postmeta_active );
}


if ( ! function_exists( 'gridread_nongrid_postmeta' ) ) :
function gridread_nongrid_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( gridread_get_option('show_post_author_home') || !(gridread_get_option('hide_posted_date_home')) || (gridread_get_option('show_comments_link_home') && (! post_password_required() && ( comments_open() || get_comments_number() ))) || gridread_get_option('show_post_categories_home') ) { ?>
    <div class="gridread-entry-meta-single">
    <?php if ( gridread_get_option('show_post_author_home') ) { ?><span class="gridread-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridread_get_option('hide_posted_date_home')) ) { ?><span class="gridread-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( gridread_get_option('show_comments_link_home') ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridread-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridread-sr-only"> on %s</span>', 'gridread' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( gridread_get_option('show_post_categories_home') ) { ?><?php gridread_single_cats(); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridread_single_cats' ) ) :
function gridread_single_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'gridread' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<span class="gridread-entry-meta-single-cats"><i class="far fa-folder-open" aria-hidden="true"></i>&nbsp;' . __( '<span class="gridread-sr-only">Posted in </span>%1$s', 'gridread' ) . '</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'gridread_single_postmeta' ) ) :
function gridread_single_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridread_get_option('hide_post_author')) || !(gridread_get_option('hide_posted_date')) || !(gridread_get_option('hide_comments_link')) || !(gridread_get_option('hide_post_categories')) || !(gridread_get_option('hide_post_edit')) ) { ?>
    <div class="gridread-entry-meta-single">
    <?php if ( !(gridread_get_option('hide_post_author')) ) { ?><span class="gridread-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridread_get_option('hide_posted_date')) ) { ?><span class="gridread-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(gridread_get_option('hide_comments_link')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridread-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridread-sr-only"> on %s</span>', 'gridread' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( !(gridread_get_option('hide_post_categories')) && has_category() ) { ?><?php gridread_single_cats(); ?><?php } ?>
    <?php if ( !(gridread_get_option('hide_post_edit')) ) { ?><?php edit_post_link( sprintf( wp_kses( /* translators: %s: Name of current post. Only visible to screen readers */ __( 'Edit<span class="gridread-sr-only"> %s</span>', 'gridread' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), '<span class="edit-link">&nbsp;&nbsp;<i class="far fa-edit" aria-hidden="true"></i> ', '</span>' ); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'gridread_page_postmeta' ) ) :
function gridread_page_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(gridread_get_option('hide_page_author')) || !(gridread_get_option('hide_page_date')) || !(gridread_get_option('hide_page_comments')) ) { ?>
    <?php if ( !((is_front_page()) && (gridread_get_option('hide_static_page_meta'))) ) { ?>
    <div class="gridread-entry-meta-single">
    <?php if ( !(gridread_get_option('hide_page_author')) ) { ?><span class="gridread-entry-meta-single-author"><i class="far fa-user-circle" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(gridread_get_option('hide_page_date')) ) { ?><span class="gridread-entry-meta-single-date"><i class="far fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(gridread_get_option('hide_page_comments')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="gridread-entry-meta-single-comments"><i class="far fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="gridread-sr-only"> on %s</span>', 'gridread' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    <?php } ?>
    <?php } ?>
<?php }
endif;